==> open-xchange-indexing_7.4.1.orig.tar.bz2: open-xchange-indexing-7.4.1/com.openexchange.mail.smal.impl/src/com/openexchange/mail/smal/impl/SmalServiceLookup.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mail.smal.impl;

import java.util.concurrent.atomic.AtomicReference;
import com.openexchange.server.ServiceLookup;
import com.openexchange.threadpool.ThreadPoolService;
import com.openexchange.threadpool.ThreadPools;

/**
 * {@link SmalServiceLookup}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class SmalServiceLookup implements ServiceLookup {

    private static final SmalServiceLookup INSTANCE = new SmalServiceLookup();

    /**
     * Gets the instance
     *
     * @return The instance
     */
    public static SmalServiceLookup getInstance() {
        return INSTANCE;
    }

    /**
     * Gets the thread pool service
     *
     * @return The thread pool or <code>null</code>
     */
    public static ThreadPoolService getThreadPool() {
        return ThreadPools.getThreadPool();
    }

    /**
     * Gets the service of specified type
     *
     * @param clazz The service's class
     * @return The service or <code>null</code> is absent
     * @throws IllegalStateException If an error occurs while returning the demanded service
     */
    public static <S> S getServiceStatic(final Class<? extends S> clazz) {
        return INSTANCE.getService(clazz);
    }

    private final AtomicReference<ServiceLookup> serviceLookupReference;

    /**
     * Initializes a new {@link SmalServiceLookup}.
     */
    private SmalServiceLookup() {
        super();
        serviceLookupReference = new AtomicReference<ServiceLookup>();
    }

    /**
     * Gets the service of specified type
     *
     * @param clazz The service's class
     * @return The service or <code>null</code> is absent
     * @throws IllegalStateException If an error occurs while returning the demanded service
     */
    @Override
    public <S> S getService(final Class<? extends S> clazz) {
        final ServiceLookup serviceLookup = serviceLookupReference.get();
        if (null == serviceLookup) {
            return null;
        }
        return serviceLookup.getService(clazz);
    }

    @Override
    public <S> S getOptionalService(final Class<? extends S> clazz) {
        final ServiceLookup serviceLookup = serviceLookupReference.get();
        if (null == serviceLookup) {
            throw new IllegalStateException("Missing Service '" + clazz.getName() + "'");
        }
        return serviceLookup.getOptionalService(clazz);
    }

    /**
     * Sets the service look-up
     *
     * @param serviceLookup The service look-up to set
     */
    public void setServiceLookup(final ServiceLookup serviceLookup) {
        serviceLookupReference.set(serviceLookup);
    }

    /**
     * Gets the service look-up
     *
     * @return The service look-up
     */
    public ServiceLookup getServiceLookup() {
        return serviceLookupReference.get();
    }

}

==> open-xchange-indexing_7.4.2.orig.tar.bz2: open-xchange-indexing-7.4.2/com.openexchange.mail.smal.impl/src/com/openexchange/mail/smal/impl/SmalServiceLookup.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mail.smal.impl;

import java.util.concurrent.atomic.AtomicReference;
import com.openexchange.server.ServiceLookup;
import com.openexchange.threadpool.ThreadPoolService;
import com.openexchange.threadpool.ThreadPools;

/**
 * {@link SmalServiceLookup}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class SmalServiceLookup implements ServiceLookup {

    private static final SmalServiceLookup INSTANCE = new SmalServiceLookup();

    /**
     * Gets the instance
     *
     * @return The instance
     */
    public static SmalServiceLookup getInstance() {
        return INSTANCE;
    }

    /**
     * Gets the thread pool service
     *
     * @return The thread pool or <code>null</code>
     */
    public static ThreadPoolService getThreadPool() {
        return ThreadPools.getThreadPool();
    }

    /**
     * Gets the service of specified type
     *
     * @param clazz The service's class
     * @return The service or <code>null</code> if absent
     * @throws IllegalStateException If an error occurs while returning the demanded service
     */
    public static <S> S getServiceStatic(final Class<? extends S> clazz) {
        return INSTANCE.getService(clazz);
    }

    private final AtomicReference<ServiceLookup> serviceLookupReference;

    /**
     * Initializes a new {@link SmalServiceLookup}.
     */
    private SmalServiceLookup() {
        super();
        serviceLookupReference = new AtomicReference<ServiceLookup>();
    }

    /**
     * Gets the service of specified type
     *
     * @param clazz The service's class
     * @return The service or <code>null</code> if absent
     * @throws IllegalStateException If an error occurs while returning the demanded service
     */
    @Override
    public <S> S getService(final Class<? extends S> clazz) {
        final ServiceLookup serviceLookup = serviceLookupReference.get();
        if (null == serviceLookup) {
            return null;
        }
        return serviceLookup.getService(clazz);
    }

    @Override
    public <S> S getOptionalService(final Class<? extends S> clazz) {
        final ServiceLookup serviceLookup = serviceLookupReference.get();
        if (null == serviceLookup) {
            throw new IllegalStateException("Missing Service '" + clazz.getName() + "'");
        }
        return serviceLookup.getOptionalService(clazz);
    }

    /**
     * Sets the service look-up
     *
     * @param serviceLookup The service look-up to set
     */
    public void setServiceLookup(final ServiceLookup serviceLookup) {
        serviceLookupReference.set(serviceLookup);
    }

    /**
     * Gets the service look-up
     *
     * @return The service look-up
     */
    public ServiceLookup getServiceLookup() {
        return serviceLookupReference.get();
    }

}
